@@ -70,7 +70,7 @@ class Base(Controller):
         ports = self.app.pargs.__dict__.get('ports') or self.app.pargs.__dict__.get('P')
         if ports: ports = [ int(p) for p in ports.split(',') ]
         else: ports = [22, 8888, 8501, 8889, 5432]
-        if not isinstance(ports, list): ports = [ports]
+        # if not isinstance(ports, list): ports = [ports]
 
 
         if self.app.pargs.action=='show':
@@ -79,6 +79,14 @@ class Base(Controller):
         elif self.app.pargs.action=='update':
             update_sg_to_ip(sg_name=self.app.pargs.name, profile=profile, ports=ports)
 
+        elif self.app.pargs.action=='ls':
+            from ..ext.aws_sg import list_security_groups
+            df = list_security_groups()
+            print(df)
+            # for sg in df.GroupId.unique():
+            #     print(f"GroupdId: {sg}")
+            #     print(df[df.GroupId==sg])
+
         else:
             raise NotImplementedError('As action, chose one of {update, show}')
 
